==> owlapi-parsers-4.0.2-sources.jar: org/semanticweb/owlapi/latex/renderer/LatexWriter.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.latex.renderer;

import java.io.PrintWriter;
import java.io.Writer;

import javax.annotation.Nonnull;

/**
 * The Class LatexWriter.
 * 
 * @author Matthew Horridge, The University Of Manchester, Medical Informatics
 *         Group
 * @since 2.0.0
 */
public class LatexWriter {

    /** The writer. */
    private final PrintWriter writer;

    /**
     * Instantiates a new latex writer.
     * 
     * @param writer
     *        the writer
     */
    public LatexWriter(Writer writer) {
        this.writer = new PrintWriter(writer);
    }

    /**
     * @param o
     *        object to write
     */
    public void write(@Nonnull Object o) {
        writer.write(o.toString());
    }

    /** Write new line. */
    public void writeNewLine() {
        writer.write("\\\\\n");
    }

    /** Write space. */
    public void writeSpace() {
        writer.write("~");
    }

    /** Write open brace. */
    public void writeOpenBrace() {
        writer.write("\\{");
    }

    /** Write close brace. */
    public void writeCloseBrace() {
        writer.write("\\}");
    }

    /** flush the writer */
    public void flush() {
        writer.flush();
    }
}

==> owlapi-parsers-5.0.5-sources.jar: org/semanticweb/owlapi/latex/renderer/LatexWriter.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.latex.renderer;

import java.io.PrintWriter;
import java.io.Writer;

/**
 * The Class LatexWriter.
 * 
 * @author Matthew Horridge, The University Of Manchester, Medical Informatics
 *         Group
 * @since 2.0.0
 */
public class LatexWriter {

    /** The writer. */
    private final PrintWriter writer;

    /**
     * Instantiates a new latex writer.
     * 
     * @param writer
     *        the writer
     */
    public LatexWriter(Writer writer) {
        this.writer = new PrintWriter(writer);
    }

    /**
     * @param o
     *        object to write
     */
    public void write(Object o) {
        writer.write(o.toString());
    }

    /** Write new line. */
    public void writeNewLine() {
        writer.write("\\\\\n");
    }

    /** Write space. */
    public void writeSpace() {
        writer.write("~");
    }

    /** Write open brace. */
    public void writeOpenBrace() {
        writer.write("\\{");
    }

    /** Write close brace. */
    public void writeCloseBrace() {
        writer.write("\\}");
    }

    /** Flush the writer. */
    public void flush() {
        writer.flush();
    }
}
